#!/bin/sh

# 
# $Author: dmc $
# $Revision: 2396 $
# $Date: 2018-12-18 11:16:27 -0400 (Tue, 18 Dec 2018) $
# $HeadURL: http://support2.silvermountaintargets.com/svn/smt/smt.common.lib/restore_backup.sh $
#

filename=${1}
originalFilename=${2}
tarzflag=""
istarfile=0
isimggz=0
is_sysupgradebin=0
unrecognized=0
mydir=${PWD}
my_tmpdir=/tmp/data-temp

# HOSTNAME='SMT_S50_server'
# SMT_IS_G2=''
# SMT_IS_R5=''
# SMT_IS_S10='1'
# SMT_IS_S3=''
# SMT_IS_S50=''
# SMT_LISTEN_PORT='80'
# SMT_MANUAL_OTHER_TARGETS='1'

[ -n "${SMT_IS_S50}" -o -n "${SMT_IS_S10}" ] && {
	echo Detected that we are a Server
}

[ -n "${SMT_IS_SOLO}" ] && {
	echo Detected that we are a SOLO
}

[ -n "${SMT_IS_G2}" ] && {
	echo Detected that we are a G2
}

echo "Determine file type ($filename}).."

# echo mydir ${mydir}

# echo "stuff to stderr" 1>&2

# "ash" shell doesn't handle word "function"
# function leave() {
leave() {
	# echo "function leave $1"
	# echo rm -rf ${my_tmpdir} ${filename}
	rm -rf ${my_tmpdir} ${filename}
	exit $1
}

rm -rf ${my_tmpdir}

mkdir -p ${my_tmpdir} || {
	echo "could not create ${my_tmpdir}"
	exit 1
}

cd ${my_tmpdir} || {
	rm -rf ${my_tmpdir}
	echo "could not cd ${my_tmpdir}"
	exit 1
}

is_software_patch=""
# is it a "tgz" software patch file?
TAR_CMD="tar xzf ${filename} >/dev/null 2>/dev/null"
eval ${TAR_CMD} extract_software_patch.sh && {
	echo "...is .tgz software patch"
	is_software_patch=1
}

# is it a "tar" software patch file?
[ -z "${is_software_patch}" ] && {
	TAR_CMD="tar xf ${filename} >/dev/null 2>/dev/null"
	eval ${TAR_CMD} extract_software_patch.sh && {
		is_software_patch=1
		echo "...is .tar software patch"
	}
}

[ -n "${is_software_patch}" ] && {
	echo "-------------Processing software patch"
	. ./extract_software_patch.sh
	echo "-------------Done sourcing extract_software_patch.sh"
	leave 0
}

echo "...NOT a software patch"

is_data_backup=""
TAR_CMD="tar xzf ${filename} >/dev/null 2>/dev/null"
eval ${TAR_CMD} ./data.txt && {
	echo "...is .tgz data backup file"
	is_data_backup=1
}

[ -z "${is_data_backup}" ] && {
	TAR_CMD="tar xf ${filename} >/dev/null 2>/dev/null"
	eval ${TAR_CMD} ./data.txt && {
		is_data_backup=1
		echo "...is .tar data backup file"
	}
}


[ -n "${is_data_backup}" ] && {
	echo "-------------Processing data backup file"
	eval ${TAR_CMD}
	chown -R `id -u`:`id -g` .
	# target might be a symbolic link
	[ -d /www/smtv2 ] && DEST=/www/smtv2/data
	[ -d /home/smt/SilverMountainTargets ] && DEST=/home/smt/SilverMountainTargets/data
	[ -z "$DEST" ] && {
		echo "***ERROR*** could not locate a destination directory, could fine neither /www/smtv2 nor /home/smt/SilverMountainTargets" 1>&2
		leave 1
	}
	mkdir ${DEST} 2>/dev/null
	rm -rf ${DEST}/*
	mv * ${DEST}
	echo "-------------Done processing data backup file"
	# exit 1
	leave 0
}

echo "...NOT a data backup file"
echo ""
echo "File type not recognized - QUITTING!!"

leave 1

exit 1




tar tzvf ${filename} 

case $originalFilename in
  (*.tar) istarfile=1; tarzflag="";;
  (*.tar.gz) istarfile=1; tarzflag="z";;
  (*.tgz) istarfile=1; tarzflag="z";;
  (*.tgz) istarfile=1; tarzflag="z";;
  (*sysupgrade.bin) is_sysupgradebin=1; ;;
  *)   
  	echo "unrecognized filetype ${filename##*.}"
  	unrecognized=1
    ;;
esac

echo filename is $filename and istarfile=$istarfile and  filetype is recognized
echo is_sysupgradebin $is_sysupgradebin

data_txt_found=0
tar t${tarzflag}f $filename ./data.txt >/dev/null 2>/dev/null && data_txt_found=1

echo data_txt_found $data_txt_found

exit 1


echo "0: $0"
echo "1: $1"
echo "2: $2"

exit 0
